diff --git a/plugins/entity/PanelizerEntityDefault.class.php b/plugins/entity/PanelizerEntityDefault.class.php
index 387dc84..f9ac1a7 100644
--- a/plugins/entity/PanelizerEntityDefault.class.php
+++ b/plugins/entity/PanelizerEntityDefault.class.php
@@ -1577,9 +1577,62 @@ abstract class PanelizerEntityDefault implements PanelizerEntityInterface {
     }
 
     // Check to see if this entity is a translation of another entity.
     // If so, use the source entity's panelizer information to clone it.
     if (isset($entity->translation_source) && isset($entity->translation_source->panelizer)) {
       $entity->panelizer = $entity->translation_source->panelizer;
+
+      ctools_include('content');
+      $plugin = ctools_get_content_type('fieldable_panels_pane');
+
+      foreach ($entity->translation_source->panelizer as $view_mode => $panelizer) {
+        // Check to see if this display mode is custom or default.
+        $default_display = $this->get_default_display_default_name($bundle, $view_mode);
+        if (empty($panelizer) || !empty($panelizer->name && $panelizer->name == $default_display)) {
+          continue;
+        }
+
+        // If it is custom, clone it deeply.
+        $panelizer_clone = clone $panelizer;
+        $panelizer_clone->display->uuid = NULL;
+        foreach ($panelizer_clone->display->content as &$pane) {
+          $pane->uuid = NULL;
+        }
+        $entity->panelizer[$view_mode] = $this->clone_panelizer($panelizer_clone, $entity);
+
+        foreach ($entity->panelizer[$view_mode]->display->content as $pid => &$pane) {
+          if ($pane->type == "fieldable_panels_pane") {
+            list($type, $id) = explode(':', $pane->subtype);
+            $content = fieldable_panels_panes_load_from_subtype_force($pane->subtype);
+
+            // Clone the entity and make sure it will get saved as a new entity.
+            $new_pane = clone $content;
+
+            $entity_info = entity_get_info('fieldable_panels_pane');
+
+            $new_pane->{$entity_info['entity keys']['id']} = FALSE;
+            if (!empty($entity_info['entity keys']['name'])) {
+              $new_pane->{$entity_info['entity keys']['name']} = FALSE;
+            }
+            $new_pane->is_new = TRUE;
+
+            // Make sure the status of a cloned exportable is custom.
+            if (!empty($entity_info['exportable'])) {
+              $status_key = isset($entity_info['entity keys']['status']) ? $entity_info['entity keys']['status'] : 'status';
+              $new_pane->$status_key = ENTITY_CUSTOM;
+            }
+
+            $new_pane->vuuid = NULL;
+            $new_pane->uuid = NULL;
+            $new_pane->vid = NULL;
+
+            $new_pane = fieldable_panels_panes_save($new_pane);
+
+            list($key, $id) = explode(':', $pane->subtype);
+            $pane->subtype = "$key:" . $new_pane->{$key};
+          }
+        }
+      }
     }
 
     // If there's no panelizer information on the entity then there is nothing to do.
@@ -1577,9 +1577,62 @@ abstract class PanelizerEntityDefault implements PanelizerEntityInterface {
 
     // Check to see if this entity is a translation of another entity.
-    // If so, use the source entity's panelizer information to clone it.
+    // If so, use the source entity's panelizer information to clone it, being
+    // careful about it being the default display.
     if (isset($entity->translation_source) && isset($entity->translation_source->panelizer)) {
       $entity->panelizer = $entity->translation_source->panelizer;
